/* MakeRKey - March 26th, 2001
**
**      Copyright (c) 1997-2001 by Gregory Braun. All rights reserved.
**
**      This function creates a System Registry Run entry.
**
**      Called:     run = a pointer to the RUN data structure to use.
**
**      Returns:    TRUE upon success, or FALSE if an error exists.
**
**      Notes:      This routine creates the following key:
**
**                      HKEY_LOCAL_MACHINE
**                        Software
**                          Microsoft
**                            Windows
**                              CurrentVersion
**                                Run
**                                  Title = d:\folder\program.exe /flags
**
*/


#include "AppPaths.h"

extern BOOL far MakeRKey (LPRUN run,BOOL user)
{
    auto HKEY   key = NULL;
    auto LONG   err = NIL;

    auto DWORD  size;
    auto DWORD  result;

    auto char sub[PSTRING];

    lstrcpy (sub,REGSTR_PATH_RUN);

    err = RegCreateKeyEx ((user) ? HKEY_CURRENT_USER : HKEY_LOCAL_MACHINE,
                          sub,
                          NIL,
                          BLANK_STR,
                          REG_OPTION_NON_VOLATILE,
                          KEY_SET_VALUE,
                          NULL,
                          &key,
                          &result);

    if (err != ERROR_SUCCESS)
        return (FALSE);

    if (*run->path) {

        size = lstrlen (run->path) + 1;

        err = RegSetValueEx (key,
                             run->name,
                             NIL,
                             REG_SZ,
                             (CONST BYTE *) run->path,
                             size);
        }

    RegCloseKey (key);

    return ((err == ERROR_SUCCESS) ? TRUE : FALSE);
}

/* end of MakeRKey.c - written by Gregory Braun */
